%% Use this file to see the spectrum of interest and the
%% first estimates of background
%% and to locate the peaks near 140 myr and 62 myr.
%% It is not necessary to compute the background spectra
%% and those steps could be deleted.  It takes only
%% about 10 seconds to run it, however.

close all;clc;clear
tic
rand('state',3)

format long g

load query_4.csv

t=query_4(:,1);
y=query_4(:,2);
y0=query_4(:,2);

for i=1:length(y)-1
    step(i)=y(i+1)-y(i);
end

%% Detrend
[P Sy]=polyfit(t,y,3);
Y0 = polyval(P,t);
y=y-Y0;
SDy=std(y);    %% all time series are normalized to have variance = 1
y=y/SDy;
LL=2^(16);
Y = fft(y,LL);
Pyy = Y.* conj(Y)/(LL);
f=[0:1:round(0.05*LL)]/LL;

plot(f,Pyy(1:round(0.05*LL)+1),'g')
ylabel('Spectral Power')
xlabel('Frequency (cycles/Myr)')
hold

% RANDOM STEP TRIAL
numtest=50
chknum=numtest/10
for itest = 1:numtest
    if chknum*fix(itest/chknum)==itest
        itest
    end
%% Permute
    yc(1,1) = y(1);
    RP=randperm(length(y)-1);
    for istep = 1:length(y)-1
        yc(istep+1,1) = yc(istep,1) + step(RP(istep));
    end
%% Detrend
    [P S]=polyfit(t,yc,3);
    Yc = polyval(P,t);
    z=yc-Yc;
    SDz=std(z);
    z=z/SDz;  %%Normalize to have variance = 1
    Y = fft(z,LL);
    Pzz = Y.* conj(Y)/(LL);
    for isa=1:round(0.05*LL)+1
        Qsave(itest,isa)=Pzz(isa);
    end
end
for isa=1:round(0.05*LL)+1
    ave(isa)=mean(Qsave(:,isa));
    sd(isa)=std(Qsave(:,isa));
end
plot(f(1:round(0.05*LL)+1),ave,'r')

%%plot(f(1:round(0.05*LL)+1),sd,'8')

%%fid=fopen('rs_FT_mollusks.dat','w');
%%for k = 1:round(0.05*LL)+1
%%    fprintf(fid,'%f  %f  %f  %f\n',f(k),Pyy(k),ave(k),sd(k));
%%end
%%fclose(fid);


% RANDOM BLOCK TRIAL
%%numtest=10000  Determined from Random Step trials.
chknum=numtest/10
for itest = 1:numtest
    if chknum*fix(itest/chknum)==itest
        itest
    end
%% Permute
    RP=randperm(20);
    is=0;
    for ib=1:20
        if RP(ib)==20
%%             for j = 1:30
             for j = 1:29
                 is = is+1;
                 yc(is,1)=y0((RP(ib)-1)*27+j);
             end
        else
             for j = 1:27
                 is = is+1;
                 yc(is,1)=y0((RP(ib)-1)*27+j);
             end
        end
    end
%% Detrend
    [P S]=polyfit(t,yc,3);
    Yc = polyval(P,t);
    z=yc-Yc;
    SDz=std(z);
    z=z/SDz; %%Normalize to have variance = 1
    Y = fft(z,LL);
    Pzz = Y.* conj(Y)/(LL);
    for isa=1:round(0.05*LL)+1
        Qsave(itest,isa)=Pzz(isa);
%%        Qsave(itest,isa)=Pzz(isa)/norm(z);
    end
end
for isa=1:round(0.05*LL)+1
    ave(isa)=mean(Qsave(:,isa));
    sd(isa)=std(Qsave(:,isa));
end

plot(f(1:round(0.05*LL)+1),ave,'b')

%% Looking for peaks between 1/f(400) = 164 myr and
%% 1/f(600) = 109 myr and between 1/f(1000)= 65.6 myr
%% and 1/f(1200) = 54.6 myr
%% The next vertical lines locate the interval being searched.

plot([f(400) f(400)],[0.4 0.8],'k--')
plot([f(600) f(600)],[0.4 0.8],'k--')
plot([f(1000) f(1000)],[0.4 0.8],'k--')
plot([f(1200) f(1200)],[0.4 0.8],'k--')

ylabel('Spectral Power')
xlabel('Frequency (cycles/Myr)')
title('G13687 ALL ENVIRONS FT')
axis([.0001 0.05 0 1])
print  -depsc dft.eps

%% bb+400 and dd+1000 are the indices to use in 
%% Check_rb and Check_rs.

[aa bb]=max(Pyy(401:600));
[bb+400 Pyy(bb+400) f(400+bb) 1/f(400+bb)]
[cc dd]=max(Pyy(1001:1200));
[dd+1000 Pyy(dd+1000) f(1000+dd) 1/f(1000+dd)]


toc
