% -----------------------------------------------------------------------------
% big_check_rs_rb.m
% James L. Cornette, 15 June, 2008
% -----------------------------------------------------------------------------
% big_check_rs_rb.m is an Octave/Matlab program adapted to compute 
% significances of several DFT spectra in a single run. The output (answer) 
% will indicate the number of times that the Monte Carlo Random Step or 
% Random Block peak has exceeded the actual FT peak. Not that the Random Block 
% trials are always larger near the 62 Myr frequency, while the Random Step 
% trials are larger near the 130 Myr frequency, therefore we use RB to 
% calculate the significance of the 62 Myr cycle and RS for the 130 Myr cycle.

close all;clc;clear
tic
rand('state',7)
format short g

load all/query_all.csv
load environs_marine/query_marine.csv
load gba/query_gba.csv
load gba/query_gba_others.csv
load gba/query_gba_others_fc.csv
load environs_nearshore/query_nearshore.csv
load environs_nearshore/query_nearshore_others_fc.csv
load environs_offshore_deep/query_offshore.csv

t=query_all(:,1);

%%This is set to compute significances of the two peaks (~60 & ~130 Myr)

AAA(1:542,1)=query_all(:,2);
AAA(1:542,2)=query_marine(:,2);
AAA(1:542,3)=query_gba(:,2);
AAA(1:542,4)=query_gba_others(:,2);
AAA(1:542,5)=query_gba_others_fc(:,2);
AAA(1:542,6)=query_nearshore(:,2);
AAA(1:542,7)=query_nearshore_others_fc(:,2);
AAA(1:542,8)=query_offshore(:,2);

NumRecords=8;

yc=zeros(size(t));
LL=2^(16);
f=[0:1:round(0.05*LL)]/LL;
numtest=10000

for kind=1:NumRecords
    kind
    y1=AAA(:,kind);
%% Detrend and compute spectrum and find the peaks near 60 & 130 Myr.
[P Sy]=polyfit(t,y1,3);
Y0 = polyval(P,t);
y1=y1-Y0;
SD1=std(y1);
y1 = y1/SD1;
Y1=fft(y1,LL);
P1=Y1.* conj(Y1)/(LL);
%%Find the max peak in f=0.0061035, p = 163.84, f=0.009140015, p=109 Myr
[a b]=max(P1(401:600));  
%%Find the max peak in f=0.0152588, p = 65.5, f=0.0182953, p=54.7 Myr
[c d]=max(P1(1001:1200));

ifreq1=400+b;
ifreq2=1000+d;


y=AAA(:,kind).';
y0=y;

for i=1:length(y)-1
    step(i)=y(i+1)-y(i);
end

icount1=0;
icount2=0;
icount3=0;
icount4=0;
for itest = 1:numtest
%%Do random step Monte Carlo    
%% Permute
    yc(1,1) = y(1);
    RP=randperm(length(y)-1);
    for istep = 1:length(y)-1
        yc(istep+1,1) = yc(istep,1) + step(RP(istep));
    end
%% Detrend
    [P S]=polyfit(t,yc,3);
    Yc = polyval(P,t);
    z=yc-Yc;
    SDz=std(z);
    z=z/SDz;  %%Normalize to have variance = 1
    Y = fft(z,LL);
    Pzz = Y.* conj(Y)/(LL);

    if Pzz(ifreq1) >= P1(ifreq1)
        icount1 = icount1 + 1;
    end
    if Pzz(ifreq2) >= P1(ifreq2)
        icount2 = icount2 + 1;
    end
%%Do random block Monte Carlo
%%Permute
    RP=randperm(20);
    is=0;
    for ib=1:20
        if RP(ib)==20
            for j = 1:29
                is = is+1;
                yc(is)=y0((RP(ib)-1)*27+j);
            end
        else
            for j = 1:27
                is = is+1;
                yc(is)=y0((RP(ib)-1)*27+j);
            end
        end
    end
            
%% Detrend

    [P S]=polyfit(t,yc,3);
    Yc = polyval(P,t);
    z=yc-Yc;
    
    SDz=std(z);
    z=z/SDz;  %%Normalize to have variance = 1
    
    Y = fft(z,LL);
    Pzz = Y.* conj(Y)/(LL);

    if Pzz(ifreq1) >= P1(ifreq1)
        icount3 = icount3 + 1;
    end
    if Pzz(ifreq2) >= P1(ifreq2)
        icount4 = icount4 + 1;
    end

end
answer(2*kind-1,1:7)=[kind  400+b a   f(400+b)  1/f(400+b) icount1 icount3];
answer(2*kind,1:7)  =[kind 1000+d c  f(1000+d) 1/f(1000+d) icount2 icount4];

end

collection_name='g21663'
column_1='subset no.'
column_2='FT imaginary index'
column_3='peak amplitude'
column_4='peak frequency (cycles/Myr)'
column_5='peak cycle (Myr)'
column_6='icount MC random step (# of times the MC step trial exceeded peak amplitude)'
column_7='icount MC random block (# of times the MC block trial exceeded peak amplitude)'
collection_subsets='1.All 2.Marine 3.GBA 4.NonGBA 5.GBA full complement 6.Nearshore 7.Nearshore full complement 8.Offshore/Deep'
answer

toc
